repo stringclasses 15
values | fix_commit stringlengths 40 40 | buggy_commit stringlengths 40 40 | message stringlengths 3 64.3k | files listlengths 1 300 | timestamp timestamp[s]date 2013-03-13 20:45:00 2026-04-11 07:48:46 |
|---|---|---|---|---|---|
ollama/ollama | 4090aca97b768e093832a5b2ed101bb867168d5c | 92ce438de06c6225ffc004600df7a1ec5a439f8e | server: send 405 instead of 404 for unallowed methods (#10275)
Fixes: #5483 | [
{
"path": "server/routes.go",
"patch": "@@ -1170,6 +1170,7 @@ func (s *Server) GenerateRoutes(rc *ollama.Registry) (http.Handler, error) {\n \tcorsConfig.AllowOrigins = envconfig.AllowedOrigins()\n \n \tr := gin.Default()\n+\tr.HandleMethodNotAllowed = true\n \tr.Use(\n \t\tcors.New(corsConfig),\n \t\tallow... | 2025-05-06T21:45:37 |
golang/go | fb41d5eb51909e777cf6c82a8eff607d7c1456b0 | 50a8b3a30ec104ce00533db47e7200e01371eaa0 | crypto/rsa: minor FIPS 186-5 compliance fixes
None of these checks actually matter, and indeed we didn't have them
before, but they are required by FIPS 186-5.
Fixes #69799
For #69536
Change-Id: I5e866962a1b2a31a753053e5b9ec50a3f4c87394
Reviewed-on: https://go-review.googlesource.com/c/go/+/632535
Auto-Submit: Filip... | [
{
"path": "src/crypto/internal/fips140/bigmod/nat.go",
"patch": "@@ -173,8 +173,10 @@ func (x *Nat) SetOverflowingBytes(b []byte, m *Modulus) (*Nat, error) {\n \tif err := x.setBytes(b); err != nil {\n \t\treturn nil, err\n \t}\n-\tleading := _W - bitLen(x.limbs[len(x.limbs)-1])\n-\tif leading < m.leading {... | 2024-11-30T16:50:31 |
facebook/react | 7dedc6cc724d168a81e0e2d7e9a943a0bb31a78e | fd007be0d07e37ccbd38b805842a89faf7a16e04 | Fix test for hook name to match lint rule | [
{
"path": "compiler/forget/src/HIR/Environment.ts",
"patch": "@@ -28,8 +28,6 @@ import {\n import { Hook } from \"./Hooks\";\n import { FunctionSignature, ShapeRegistry } from \"./ObjectShape\";\n \n-const HOOK_PATTERN = /^_?use/;\n-\n // TODO(mofeiZ): User defined global types (with corresponding shapes).\... | 2023-05-08T19:14:30 |
electron/electron | f60ff18b1488b5ba28d930d22924816452a638e4 | 7e59d784a0b5c922564cbc8c55f95f0e7daf6997 | fix: gn check when //printing component is disabled (#33429) | [
{
"path": "shell/browser/api/electron_api_web_contents.cc",
"patch": "@@ -167,7 +167,7 @@\n #if BUILDFLAG(ENABLE_PRINTING)\n #include \"components/printing/browser/print_manager_utils.h\"\n #include \"printing/backend/print_backend.h\" // nogncheck\n-#include \"printing/mojom/print.mojom.h\"\n+#include \"p... | 2022-03-25T03:48:23 |
huggingface/transformers | 403990cadb8aceac02aaa2b6ec1016105249a738 | 5405f80e0e7bca9206445e36f510821b294bf051 | fix(models): Preserve custom token IDs through DiaConfig save and load (#43928)
* fix: Preserve custom token IDs in DiaConfig save and load
* refactor: Address review comments | [
{
"path": "src/transformers/models/dia/configuration_dia.py",
"patch": "@@ -145,6 +145,12 @@ class DiaDecoderConfig(PreTrainedConfig):\n Whether or not the model should return the last key/values attentions (not used by all models).\n is_encoder_decoder (`bool`, *optional*, defaults to `... | 2026-02-13T09:28:26 |
ggml-org/llama.cpp | 88d5f8ffc398f9d6dbe529e3f0f0c739eabeafa7 | d43375ff7f73e5098837c20512aa58f4bc8edb02 | CUDA/HIP: Fix kernel slection for mmvq mmid kernel to align host selection with device launch bounds (#21238)
The conditions cc == GGML_CUDA_CC_VOLTA || cc >= GGML_CUDA_CC_ADA_LOVELACE and cc >= GGML_CUDA_CC_TURING match all non-nvidia devices. This causes us to attempt to launch the kernel for batch sizes with larger... | [
{
"path": "ggml/src/ggml-cuda/mmvq.cu",
"patch": "@@ -235,30 +235,33 @@ static constexpr __host__ __device__ int get_mmvq_mmid_max_batch_rdna4(ggml_type\n // Host function: returns the max batch size for the current arch+type at runtime.\n int get_mmvq_mmid_max_batch(ggml_type type, int cc) {\n // NVIDI... | 2026-04-01T08:21:20 |
golang/go | 50a8b3a30ec104ce00533db47e7200e01371eaa0 | 7632c6e2bd67b37a943f2714f3e53eebb354e18a | hash/maphash, cmd/compile: make Comparable[string] not escape its argument
Currently, maphash.Comparable forces its argument to escape if it
contains a pointer, as we cannot hash stack pointers, which will
change when the stack moves. However, for a string, it is actually
okay if its data pointer points to the stack, ... | [
{
"path": "src/cmd/compile/internal/escape/call.go",
"patch": "@@ -10,6 +10,7 @@ import (\n \t\"cmd/compile/internal/typecheck\"\n \t\"cmd/compile/internal/types\"\n \t\"cmd/internal/src\"\n+\t\"strings\"\n )\n \n // call evaluates a call expressions, including builtin calls. ks\n@@ -82,6 +83,29 @@ func (e ... | 2024-12-02T04:53:23 |
ollama/ollama | 95e744beeb82f725579932336eeabc0de019cbf4 | 3b2d2c8326c245f0210a549777d0a77c2ccd92d1 | discover: fix compiler warnings (#10572) | [
{
"path": "discover/gpu_info.h",
"patch": "@@ -27,12 +27,14 @@\n \n #endif\n \n+#ifndef LOG\n #define LOG(verbose, ...) \\\n do { \\\n if (verbose) { \\\n fprintf(stderr, __VA_ARGS__); \\\n } \\\n } while (0)\n+#endif\n \n #ifdef __cplusplus\n extern \"C\" {",
"additions": 2,
"dele... | 2025-05-06T17:49:22 |
facebook/react | fd007be0d07e37ccbd38b805842a89faf7a16e04 | 6bbe3111c08c5c00a37f12aa6c1dc1f086a8b938 | Fixtures from ESLint rule
Incorporates the fixtures from eslint-plugin-react-hooks using a script, so that
we can easily update them in the future. For each fixture we run the compiler
with and without hooks validation first so that we know if the fixture is
expected to pass — we have some false positives and fals... | [
{
"path": "compiler/forget/package.json",
"patch": "@@ -49,6 +49,7 @@\n \"@babel/traverse\": \"^7.19.1\",\n \"@testing-library/react\": \"^13.4.0\",\n \"@tsconfig/node16-strictest\": \"^1.0.3\",\n+ \"@types/glob\": \"^8.1.0\",\n \"@types/invariant\": \"^2.2.35\",\n \"@types/jest\": \"... | 2023-05-08T19:10:43 |
huggingface/transformers | 5405f80e0e7bca9206445e36f510821b294bf051 | d0c054bae1c0a83173dba18cf2b17996a0f8dae1 | [Doc tests] Fix bug (#43729)
* Fix bug
* Remove BUG.md | [
{
"path": "docs/source/en/model_doc/eomt_dinov3.md",
"patch": "@@ -52,30 +52,26 @@ Below is a minimal example showing how to run panoptic segmentation with a DINOv\n image processor can be reused for semantic or instance segmentation simply by swapping the checkpoint.\n \n ```python\n-import matplotlib.pypl... | 2026-02-13T09:17:43 |
ggml-org/llama.cpp | d43375ff7f73e5098837c20512aa58f4bc8edb02 | 2b86e5cae616c167b9c730c93138f26bba724adf | ggml : fix RWKV ops thread assignment (#21226) | [
{
"path": "ggml/src/ggml-cpu/ggml-cpu.c",
"patch": "@@ -2350,11 +2350,15 @@ static int ggml_get_n_tasks(struct ggml_tensor * node, int n_threads) {\n case GGML_OP_FLASH_ATTN_BACK:\n case GGML_OP_SSM_CONV:\n case GGML_OP_SSM_SCAN:\n+ {\n+ n_tasks = n_threads;... | 2026-04-01T08:10:25 |
electron/electron | 7e59d784a0b5c922564cbc8c55f95f0e7daf6997 | 92c5dedc76275fb84814aa05ab71c85d84a05663 | chore: bump chromium to 102.0.4961.0 (main) (#33091)
* chore: bump chromium in DEPS to 101.0.4911.0
* chore: bump chromium in DEPS to 101.0.4913.0
* chore: bump chromium in DEPS to 101.0.4915.0
* chore: bump chromium in DEPS to 101.0.4917.0
* chore: bump chromium in DEPS to 101.0.4919.0
* chore: bump ch... | [
{
"path": ".eslintrc.json",
"patch": "@@ -1,4 +1,5 @@\n {\n+ \"root\": true,\n \"extends\": \"standard\",\n \"parser\": \"@typescript-eslint/parser\",\n \"plugins\": [\"@typescript-eslint\"],",
"additions": 1,
"deletions": 0,
"language": "JSON"
},
{
"path": "BUILD.gn",
"patch"... | 2022-03-25T01:39:03 |
golang/go | 7632c6e2bd67b37a943f2714f3e53eebb354e18a | 3374abeb50bbf31b7f4d2c7986d08384d673447d | cmd/go: add go prefix in base.Fatalf
For #70537
Change-Id: I20e239611f07aa13915367c3a44994a43b5482d7
Reviewed-on: https://go-review.googlesource.com/c/go/+/631535
LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com>
Reviewed-by: Veronica Silina <veronicasilina@google.com>
Reviewed... | [
{
"path": "src/cmd/go/internal/auth/auth.go",
"patch": "@@ -60,18 +60,18 @@ func runGoAuth(client *http.Client, res *http.Response, url string) {\n \t\tcommand = strings.TrimSpace(command)\n \t\twords := strings.Fields(command)\n \t\tif len(words) == 0 {\n-\t\t\tbase.Fatalf(\"GOAUTH encountered an empty com... | 2024-11-24T11:34:30 |
ollama/ollama | d931ee8f22d38a87d4ff1886ccf56c38697f3fa0 | 70736007976543a9f54bbdb9e484478ad3af21a0 | create blobs in parallel (#10135)
* default max term height
* error on out of tree files | [
{
"path": "cmd/cmd.go",
"patch": "@@ -31,6 +31,7 @@ import (\n \t\"github.com/olekukonko/tablewriter\"\n \t\"github.com/spf13/cobra\"\n \t\"golang.org/x/crypto/ssh\"\n+\t\"golang.org/x/sync/errgroup\"\n \t\"golang.org/x/term\"\n \n \t\"github.com/ollama/ollama/api\"\n@@ -41,6 +42,7 @@ import (\n \t\"github.... | 2025-05-05T18:59:26 |
facebook/react | 7ac5e9a602347f3b7d26c60a549c483d3bc88bbf | 16d053d592673dd5565d85109f259371b23f87e8 | Small flowconfig fixes (#26784)
- The whole project root is included by default anyway, the include
section should be redundant and just misleading.
- The generated ignore paths ignore more than intended as they didn't
escape the `.` for regex.
Test Plan:
- wait for CI
- tested the ignore pattern change with r... | [
{
"path": "scripts/flow/config/flowconfig",
"patch": "@@ -18,11 +18,6 @@\n \n %REACT_RENDERER_FLOW_IGNORES%\n \n-[include]\n-./node_modules/\n-./packages/\n-./scripts/\n-\n [libs]\n ./node_modules/fbjs/flow/lib/dev.js\n ./scripts/flow/environment.js",
"additions": 0,
"deletions": 5,
"language": ... | 2023-05-08T16:07:48 |
huggingface/transformers | d0c054bae1c0a83173dba18cf2b17996a0f8dae1 | 609e3d585bfe2f78e95f18761dd85ae753da5f1b | [kernels] fix kernel versions (#43955)
fix | [
{
"path": "src/transformers/integrations/hub_kernels.py",
"patch": "@@ -274,9 +274,9 @@ def register_kernel_mapping_transformers(*args, **kwargs):\n \n \n _HUB_KERNEL_MAPPING: dict[str, dict[str, str]] = {\n- \"causal-conv1d\": {\"repo_id\": \"kernels-community/causal-conv1d\"},\n- \"mamba-ssm\": {\"r... | 2026-02-13T07:32:30 |
ggml-org/llama.cpp | 2b86e5cae616c167b9c730c93138f26bba724adf | 88458164c77509d2022e45f71aaf97040667abe2 | ggml-cpu: fix fallback for RVV kernels without zvfh (#21157)
* ggml-cpu: refactor sgemm; fix rvv checks
* ggml-cpu: refactor rvv kernels; set zvfbfwma default to off | [
{
"path": "ggml/CMakeLists.txt",
"patch": "@@ -166,15 +166,16 @@ if (NOT MSVC)\n option(GGML_AMX_INT8 \"ggml: enable AMX-INT8\" OFF)\n option(GGML_AMX_BF16 \"ggml: enable AMX-BF16\" OFF)\n endif()\n-option(GGML_LASX \"ggml: enable lasx\" ON)\n-option(G... | 2026-04-01T08:10:03 |
electron/electron | 4fdf8584ed6820a1b464cabc80c41acedbbce814 | 962f4a6558af1bc132c0df324581636d22c695cf | docs: fix SCA and postMessage links in web-frame-main.md (#33415) | [
{
"path": "docs/api/web-frame-main.md",
"patch": "@@ -195,3 +195,6 @@ have the same `routingId`.\n A `string` representing the [visibility state](https://developer.mozilla.org/en-US/docs/Web/API/Document/visibilityState) of the frame.\n \n See also how the [Page Visibility API](browser-window.md#page-visibi... | 2022-03-24T17:12:47 |
golang/go | 3374abeb50bbf31b7f4d2c7986d08384d673447d | e5489a34ca2c31608821d3ac4ec07892fb6a2272 | testing: consider -N suffix after benchmark name optional
A "-N" suffix is left out when GOMAXPROCS is 1.
Also match at least 1 space (\s+ instead of \s*), remove trailing '.*'
(it's a no-op), and make the test error message style more consistent
while here.
For #61515.
Fixes #70627.
Change-Id: Id0a17478ac31e2934a6... | [
{
"path": "src/testing/testing_test.go",
"patch": "@@ -990,9 +990,9 @@ func TestBenchmarkBLoopIterationCorrect(t *testing.T) {\n \t\tt.Errorf(\"got %d loop rampup; want %d\", c, want)\n \t}\n \n-\tre := regexp.MustCompile(`BenchmarkBLoopPrint-[0-9]+\\s*2\\s*[0-9]+\\s*ns/op.*`)\n+\tre := regexp.MustCompile(`... | 2024-12-01T22:22:19 |
ollama/ollama | 70736007976543a9f54bbdb9e484478ad3af21a0 | b1c40138dadfd32550ae03391bdee63ef5e2b8bb | ggml: Reduce log level of "key not found"
Most of the time this is not an error. | [
{
"path": "fs/ggml/ggml.go",
"patch": "@@ -149,7 +149,7 @@ func keyValue[T valueTypes | arrayValueTypes](kv KV, key string, defaultValue ..\n \t\treturn val.(T)\n \t}\n \n-\tslog.Warn(\"key not found\", \"key\", key, \"default\", defaultValue[0])\n+\tslog.Debug(\"key not found\", \"key\", key, \"default\", ... | 2025-05-05T17:37:16 |
ggml-org/llama.cpp | 88458164c77509d2022e45f71aaf97040667abe2 | 49512502359b9d3a5ea589c215396513c53fe064 | CUDA: Add Flash Attention Support for Head Dimension 512 (#20998)
* flash attention support for head dimension 512 added
* FA D=512 - match 576 configs, limit ncols2, revert vec cap
* fix HIP tile kernel build for D=512
* fix HIP tile kernel occupancy for D=512 on AMD
* Apply suggestions from code review
Co-autho... | [
{
"path": "ggml/src/ggml-cuda/fattn-mma-f16.cuh",
"patch": "@@ -66,6 +66,11 @@ static constexpr __host__ __device__ fattn_mma_config ggml_cuda_fattn_mma_get_co\n GGML_CUDA_FATTN_MMA_CONFIG_CASE(256, 256, 32, 128, 2, 32, 128, 128, 128, 2, true);\n GGML_CUDA_FATTN_MMA_CONFIG_CASE(256, 256, 64, 128, 2... | 2026-04-01T07:07:24 |
facebook/react | 6bbe3111c08c5c00a37f12aa6c1dc1f086a8b938 | 2ddd00dbb1771617565133a01eb61a8c8e1d358d | ValidateUnconditionalHooks pass using dominators
See the code comments for more, but the basic idea here is that we use the post
dominator tree to find the set of basic blocks which are guaranteed reachable in
each function. Those are the only blocks where it is safe to call hooks, and we
error for hook calls in a... | [
{
"path": "compiler/forget/src/CompilerPipeline.ts",
"patch": "@@ -15,6 +15,7 @@ import {\n validateConsistentIdentifiers,\n validateHooksUsage,\n validateTerminalSuccessors,\n+ validateUnconditionalHooks,\n } from \"./HIR\";\n import { Environment, EnvironmentConfig } from \"./HIR/Environment\";\n i... | 2023-05-08T15:55:14 |
huggingface/transformers | 609e3d585bfe2f78e95f18761dd85ae753da5f1b | c8f112d449ffa330887838218dccbe2ab9e4c99e | Fix LASR test layerdrop issue (#43954)
Fix LASR layerdrop issue | [
{
"path": "tests/models/lasr/test_modeling_lasr.py",
"patch": "@@ -54,6 +54,7 @@ def __init__(\n subsampling_conv_channels=32,\n subsampling_conv_kernel_size=5,\n subsampling_conv_stride=2,\n+ layerdrop=0.0,\n ):\n # testing suite parameters\n self.parent =... | 2026-02-12T17:03:40 |
golang/go | c5adb8216968be46bd11f7b7360a7c8bde1258d9 | dd7ab5ec5d6329dd5da052d2438274572ad7113b | crypto/rsa: check hash message length first in SignPKCS1v15
This restores the error checking behavior from Go 1.23.
In particular, the boringcrypto code path now contains this
check again.
Change-Id: Ie38c68c27bc3a95c6a0b5a78fc4196694527cd6b
Reviewed-on: https://go-review.googlesource.com/c/go/+/632495
LUCI-TryBot-Re... | [
{
"path": "src/crypto/rsa/fips.go",
"patch": "@@ -278,6 +278,14 @@ func decryptOAEP(hash, mgfHash hash.Hash, priv *PrivateKey, ciphertext []byte, l\n // messages to signatures and identify the signed messages. As ever,\n // signatures provide authenticity, not confidentiality.\n func SignPKCS1v15(random io.... | 2024-11-30T01:30:48 |
ollama/ollama | b1c40138dadfd32550ae03391bdee63ef5e2b8bb | 17466217e55091e4380b7b3fc7684a2476fdba57 | win: lint fix (#10571) | [
{
"path": "llm/llm_windows.go",
"patch": "@@ -7,7 +7,7 @@ import (\n const (\n \tCREATE_DEFAULT_ERROR_MODE = 0x04000000\n \tABOVE_NORMAL_PRIORITY_CLASS = 0x00008000\n- CREATE_NO_WINDOW = 0x08000000\n+\tCREATE_NO_WINDOW = 0x08000000\n )\n \n var LlamaServerSysProcAttr = &syscall... | 2025-05-05T18:08:12 |
electron/electron | db5a3c014ae17e464fcd1fa6bfcd05a40ea2ed71 | cc253f5de96dc4f798673b0bbb5cb2c49ea2b7ce | chore: bump node to v16.14.2 (main) (#32833)
* chore: bump node in DEPS to v16.14.0
* src: add flags for controlling process behavior
https://github.com/nodejs/node/pull/40339
* src: add x509.fingerprint512 to crypto module
https://github.com/nodejs/node/pull/39809
* deps: upgrade to libuv 1.43.0
htt... | [
{
"path": "DEPS",
"patch": "@@ -17,7 +17,7 @@ vars = {\n 'chromium_version':\n '100.0.4894.0',\n 'node_version':\n- 'v16.13.2',\n+ 'v16.14.2',\n 'nan_version':\n # The following commit hash of NAN is v2.14.2 with *only* changes to the\n # test suite. This should be updated to a speci... | 2022-03-23T22:59:54 |
facebook/react | f75cf6fe386ef46cfa6b3fd100a287db31b05a98 | 407e7b0c620d1bb20ce52ccaa8e8ae555ab3edc4 | Fix fbt (again) | [
{
"path": "compiler/forget/src/ReactiveScopes/MemoizeFbtOperandsInSameScope.ts",
"patch": "@@ -65,20 +65,20 @@ class Transform extends ReactiveFunctionVisitor<void> {\n (value.kind === \"CallExpression\" &&\n this.fbtValues.has(value.callee.identifier.id))\n ) {\n+ const fbtScope = lv... | 2023-05-04T22:19:41 |
huggingface/transformers | c8f112d449ffa330887838218dccbe2ab9e4c99e | 53a49c482a3ec1fdf97a6e60785790a7c99858fd | Fix typos in docstrings, comments, and error messages (#43949)
* Fix: Correct typos in docstrings and error messages across src/transformers
* Fix: Address code review feedback (grammar, typos, and filename corrections)
* Fix: Address minor code review feedback(filename fix) | [
{
"path": "src/transformers/cache_utils.py",
"patch": "@@ -878,7 +878,7 @@ def max_cache_len(self) -> int:\n \n @property\n def is_compileable(self) -> bool:\n- \"\"\"Return whether the cache is compileable\"\"\"\n+ \"\"\"Return whether the cache is compilable\"\"\"\n # For Dyn... | 2026-02-12T16:26:09 |
ggml-org/llama.cpp | 0fcb3760b2b9a3a496ef14621a7e4dad7a8df90f | 6307ec07d3ad730f21886fb484cdb4abe1e74091 | fix: Use lower-case proxy headers naming (#21235) | [
{
"path": "tools/server/public/index.html",
"patch": "@@ -18,7 +18,7 @@\n \t\t<div style=\"display: contents\">\n \t\t\t<script>\n \t\t\t\t{\n-\t\t\t\t\t__sveltekit_1snwavw = {\n+\t\t\t\t\t__sveltekit_1trm5n9 = {\n \t\t\t\t\t\tbase: new URL('.', location).pathname.slice(0, -1)\n \t\t\t\t\t};\n ",
"addit... | 2026-03-31T15:47:46 |
ollama/ollama | 1703d1472ed2ff257fe338ddf83e199316f8b5b7 | 913905028badc32a8283750c5342340113269865 | server: fix panic when runner.Options is nil (#10566) | [
{
"path": "server/sched.go",
"patch": "@@ -691,11 +691,13 @@ func (runner *runnerRef) LogValue() slog.Value {\n \tattrs = append(attrs,\n \t\tslog.String(\"size\", format.HumanBytes2(runner.estimatedTotal)),\n \t\tslog.String(\"vram\", format.HumanBytes2(runner.estimatedVRAM)),\n-\t\tslog.Int(\"num_ctx\", r... | 2025-05-05T16:01:33 |
golang/go | c5c4f3dd5f5e5a6a27fe53dc57eaf6acf414a4bc | acd54c99857bd5e8030cd8d1adaef0f324799224 | crypto/x509: keep RSA CRT values in ParsePKCS1PrivateKey
Turns out that recomputing them (and qInv in particular) in constant
time is expensive, so let's not throw them away when they are available.
They are much faster to check, so we now do that on precompute.
Also, thanks to the opaque crypto/internal/fips140/rsa.... | [
{
"path": "doc/godebug.md",
"patch": "@@ -208,6 +208,11 @@ X25519MLKEM768 by default. The default can be reverted using the\n [`tlsmlkem` setting](/pkg/crypto/tls/#Config.CurvePreferences).\n Go 1.24 also removed X25519Kyber768Draft00 and the Go 1.23 `tlskyber` setting.\n \n+Go 1.24 made [`ParsePKCS1Private... | 2024-11-29T14:38:48 |
electron/electron | f912130be6731e2636ed31f6da6e7a1d1d9e8b9d | a5ab10f3d2370aa8c3d9abb409776dc4875966af | fix: libuv patches to address child_process.spawn slowness (#33337)
* fix: libuv patches to address child_process.spawn slowness
* chore: backport additional patches
Co-authored-by: deepak1556 <hop2deep@gmail.com> | [
{
"path": "patches/node/.patches",
"patch": "@@ -35,3 +35,14 @@ fix_failing_node_js_test_on_outdated.patch\n be_compatible_with_cppgc.patch\n feat_add_knostartdebugsignalhandler_to_environment_to_prevent.patch\n worker_thread_add_asar_support.patch\n+process_monitor_for_exit_with_kqueue_on_bsds_3441.patch\n... | 2022-03-23T13:30:54 |
facebook/react | 783e7fcfa3e354b3be13f5403fc2fd2260db00b4 | 377c5175f78e47a3f01d323ad6528a696c88b76e | React DevTools 4.27.6 -> 4.27.7 (#26780)
List of changes:
* DevTools: fix backend activation ([hoxyq](https://github.com/hoxyq) in
[#26779](https://github.com/facebook/react/pull/26779))
* fix[dynamic-scripts-injection]: unregister content scripts before
registration ([hoxyq](https://github.com/hoxyq) in
[#26765]... | [
{
"path": "packages/react-devtools-core/package.json",
"patch": "@@ -1,6 +1,6 @@\n {\n \"name\": \"react-devtools-core\",\n- \"version\": \"4.27.6\",\n+ \"version\": \"4.27.7\",\n \"description\": \"Use react-devtools outside of the browser\",\n \"license\": \"MIT\",\n \"main\": \"./dist/backend.j... | 2023-05-04T17:22:47 |
ggml-org/llama.cpp | 632219af73c0cabeae44e8f2e8d6d5478d153f52 | 4a00bbfed62a9714bc94a3431e6cc37615b175a2 | CANN: fix multi-thread set_tensor race conditions (#20151)
* CANN: fix multi-thread set_tensor race conditions
When ollama calls ggml_backend_tensor_set from multiple threads (each
writing a different chunk of the same tensor), the CANN backend had
three concurrency issues:
1. Quantized tensors (Q4_0/Q8_0) require a... | [
{
"path": "ggml/src/ggml-cann/aclnn_ops.cpp",
"patch": "@@ -434,6 +434,9 @@ void ggml_cann_norm(ggml_backend_cann_context & ctx, ggml_tensor * dst) {\n void ggml_cann_l2_norm(ggml_backend_cann_context & ctx, ggml_tensor * dst) {\n ggml_tensor * src = dst->src[0];\n \n+ float eps;\n+ memcpy(&eps, d... | 2026-03-31T14:00:51 |
huggingface/transformers | 53a49c482a3ec1fdf97a6e60785790a7c99858fd | 3b8f0948af563f86539d570c9091e1ca02f88730 | Fix `get_number_of_image_tokens` (#43948)
* fix
* fix tests
* this test not needed anymore, teh new one tests better | [
{
"path": "src/transformers/models/emu3/image_processing_emu3.py",
"patch": "@@ -217,11 +217,10 @@ def _preprocess(\n # We assume that all images have the same channel dimension format.\n input_data_format = infer_channel_dimension_format(images[0])\n \n- height, width = get_i... | 2026-02-12T16:23:37 |
ollama/ollama | 913905028badc32a8283750c5342340113269865 | 7e5c8eee5c65bcf7c0d46d5fe3b084fd70d36015 | all: fix cgo compiler warnings on windows (#10563) | [
{
"path": "discover/gpu_info_cudart.c",
"patch": "@@ -58,7 +58,7 @@ void cudart_init(char *cudart_lib_path, cudart_init_resp_t *resp) {\n LOG(resp->ch.verbose, \"cudaSetDevice err: %d\\n\", ret);\n UNLOAD_LIBRARY(resp->ch.handle);\n resp->ch.handle = NULL;\n- if (ret == CUDA_ERROR_INSUFFICIEN... | 2025-05-05T15:02:39 |
golang/go | 7d7192e54f4d4eb51018ad128c25d52e26f02a3f | fa38b41be94f66d3d49e10f673643105f44fe540 | crypto/rsa: move precomputation to crypto/internal/fips140/rsa
We are severely limited by the crypto/rsa API in a few ways:
- Precompute doesn't return an error, but is the only function allowed
to modify a PrivateKey.
- Clients presumably expect the PrecomputedValues big.Ints to be
populated after Precomput... | [
{
"path": "doc/next/6-stdlib/99-minor/crypto/x509/69799.md",
"patch": "@@ -0,0 +1,3 @@\n+[MarshalPKCS8PrivateKey] now returns an error instead of marshaling an invalid\n+RSA key. ([MarshalPKCS1PrivateKey] doesn't have an error return, and its behavior\n+when provided invalid keys continues to be undefined.)... | 2024-11-29T12:15:11 |
facebook/react | 377c5175f78e47a3f01d323ad6528a696c88b76e | aef7ce5547c9489dc48e31f69b002cd17206e0cb | DevTools: fix backend activation (#26779)
## Summary
We have a case:
1. Open components tab
2. Close Chrome / Firefox devtools window completely
3. Reopen browser devtools panel
4. Open components tab
Currently, in version 4.27.6, we cannot load the components tree.
This PR contains two changes:
- non-func... | [
{
"path": "packages/react-devtools-extensions/src/backendManager.js",
"patch": "@@ -61,6 +61,13 @@ function setup(hook: ?DevToolsHook) {\n hook.renderers.forEach(renderer => {\n registerRenderer(renderer);\n });\n+\n+ // Activate and remove from required all present backends, registered within the ... | 2023-05-04T16:34:57 |
electron/electron | 3744ac0a520562e08ecc4ec5f88f059818a0ad1e | 800b96fe142446faa08aa0d380e71e3bea79b12f | fix: persist BrowserView content bounds when calculating layout (#32747)
Reverting change introduced in PR: https://github.com/electron/electron/pull/30510
Co-authored-by: Andreas Johansson <aj3621@tobii.com> | [
{
"path": "shell/browser/ui/views/inspectable_web_contents_view_views.cc",
"patch": "@@ -214,7 +214,7 @@ void InspectableWebContentsViewViews::SetTitle(const std::u16string& title) {\n \n void InspectableWebContentsViewViews::Layout() {\n if (!devtools_web_view_->GetVisible()) {\n- contents_web_view_->... | 2022-03-23T01:16:15 |
huggingface/transformers | 3b8f0948af563f86539d570c9091e1ca02f88730 | 0aebdc5c699796bf162e768defa34ffb9a02cc3a | Fix qwen-vl position ids when generating several times (#43952)
* fix
* rope delta can't be negative
* extend the test to check `generate` as well | [
{
"path": "src/transformers/models/ernie4_5_vl_moe/modeling_ernie4_5_vl_moe.py",
"patch": "@@ -1716,9 +1716,12 @@ def _prepare_position_ids_for_generation(self, inputs_tensor, model_kwargs):\n text_positions = super()._prepare_position_ids_for_generation(inputs_tensor, model_kwargs)\n \n # E... | 2026-02-12T16:22:38 |
ollama/ollama | 6a74bba7e7e19bf5f5aeacb039a1537afa3522a5 | 76ea735aafe8cd3165a105b70ca427dce9d7aec4 | win: ensure ollama paths come first (#10549)
For all search path env vars make sure our dirs are first
to avoid potentially finding other incompatible libraries
on the users system.
Also fixes a minor build script glitch for windows rocm | [
{
"path": "llm/server.go",
"patch": "@@ -325,7 +325,9 @@ func NewLlamaServer(gpus discover.GpuInfoList, modelPath string, f *ggml.GGML, a\n \t\t\tpathEnv = \"LD_LIBRARY_PATH\"\n \t\t}\n \n-\t\tvar libraryPaths []string\n+\t\t// Note: we always put our dependency paths first\n+\t\t// since these are the exac... | 2025-05-03T20:11:48 |
ggml-org/llama.cpp | 4a00bbfed62a9714bc94a3431e6cc37615b175a2 | 624733d631ac3197afa4f9aa701f56f184fdde69 | server: (webui) no more gzip compression (#21073)
* webui: no more gzip
* try changing a small line
* Revert "try changing a small line"
This reverts commit 0d7a3531593d87b724d404c8727a96becab3ab07.
* fix lint
* fix test
* rebuild
* split into html/css/js
* lint
* chore: update webui build output
* chore: Up... | [
{
"path": ".editorconfig",
"patch": "@@ -21,14 +21,6 @@ indent_style = tab\n [prompts/*.txt]\n insert_final_newline = unset\n \n-[tools/server/public/*]\n-indent_size = 2\n-\n-[tools/server/public/deps_*]\n-trim_trailing_whitespace = unset\n-indent_style = unset\n-indent_size = unset\n-\n [tools/server/deps... | 2026-03-31T13:44:26 |
golang/go | fa38b41be94f66d3d49e10f673643105f44fe540 | f7475a0af3169d3d91f6071646defcf103393cc0 | crypto/internal/fips140/rsa: check that e and N are odd
N needs to be odd or we can't call Nat.Exp with it. This was previously
enforced at the Modulus level, but was relaxed in CL 630515.
While at it, also assert that e is odd. If it's even, there is no
possible corresponding private key, and we might as well error ... | [
{
"path": "src/crypto/internal/fips140/rsa/rsa.go",
"patch": "@@ -115,15 +115,23 @@ func checkPublicKey(pub *PublicKey) error {\n \tif pub.N == nil {\n \t\treturn errors.New(\"crypto/rsa: missing public modulus\")\n \t}\n+\tif pub.N.Nat().IsOdd() == 0 {\n+\t\treturn errors.New(\"crypto/rsa: public modulus i... | 2024-11-28T18:55:53 |
facebook/react | aef7ce5547c9489dc48e31f69b002cd17206e0cb | c10010a6a00911fe99452bc561dd47c3e15f4eb8 | [Flight] Progressively Enhanced Server Actions (#26774)
This automatically exposes `$$FORM_ACTIONS` on Server References coming
from Flight. So that when they're used in a form action, we can encode
the ID for the server reference as a hidden field or as part of the name
of a button.
If the Server Action is a bo... | [
{
"path": "fixtures/flight/server/global.js",
"patch": "@@ -95,6 +95,8 @@ app.all('/', async function (req, res, next) {\n if (req.get('rsc-action')) {\n proxiedHeaders['Content-type'] = req.get('Content-type');\n proxiedHeaders['rsc-action'] = req.get('rsc-action');\n+ } else if (req.get('Conten... | 2023-05-03T22:36:57 |
electron/electron | 06a00b74e817a61f20e2734d50d8eb7bc9b099f6 | 27ddf19f3ce34f0153d29e23f68b6c38b206f296 | fix: initialize asar support in worker threads (#33216)
* fix: initialize asar support in worker threads
Use `ObjectWrap` instead of gin's Wrap in `electron_api_asar.cc` because
gin isn't fully initialized (and apparently not possible to initialize
without ruining the isolate configuration and array buffer alloca... | [
{
"path": "lib/asar/fs-wrapper.ts",
"patch": "@@ -30,11 +30,13 @@ const getOrCreateArchive = (archivePath: string) => {\n return cachedArchives.get(archivePath);\n }\n \n- const newArchive = asar.createArchive(archivePath);\n- if (!newArchive) return null;\n-\n- cachedArchives.set(archivePath, newA... | 2022-03-23T00:37:55 |
huggingface/transformers | 2a232cd952b81253762f86bb0e6ca3170a685e31 | 2caa05deb31d7a8e641bbf6b64571fa4fc9c593e | fix: Better weight decay exclusion in `run_*_no‑trainer.py` examples (#43947)
more robust weight decay detection | [
{
"path": "examples/pytorch/image-classification/run_image_classification_no_trainer.py",
"patch": "@@ -41,6 +41,7 @@\n from accelerate.utils import set_seed\n from datasets import load_dataset\n from huggingface_hub import HfApi\n+from torch import nn\n from torch.utils.data import DataLoader\n from torchv... | 2026-02-12T14:36:36 |
ollama/ollama | 76ea735aafe8cd3165a105b70ca427dce9d7aec4 | dd1d4e99e7e8475d1669f566bb5c0ae30db419f1 | sched: logging improvements (#10550)
This enhances our logging in the scheduler. The initial "waiting for server" log
no longer claims an initial error state (now "not responding" which better reflects
the actual state). Runners now have slog wiring to report more details about the
runner, including PID. | [
{
"path": "llm/server.go",
"patch": "@@ -44,6 +44,7 @@ type LlamaServer interface {\n \tEstimatedVRAM() uint64 // Total VRAM across all GPUs\n \tEstimatedTotal() uint64\n \tEstimatedVRAMByGPU(gpuID string) uint64\n+\tPid() int\n }\n \n // llmServer is an instance of the llama.cpp server\n@@ -520,6 +521,9 @@... | 2025-05-03T19:01:56 |
ggml-org/llama.cpp | 0b6ff47996019d559862d279ccb66dd9390934cd | eec6f85d7b84c368b2e59e1dab9f2bad56d239f7 | fix: correct misspellings in code comments (#21217)
- emdeddings → embeddings (gemma3.cpp, gemma3n-iswa.cpp,
gemma-embedding.cpp)
- imlpemented → implemented (llama-adapter.cpp)
- interere → interfere (llama-graph.cpp)
- overridde → overridden (chat.cpp)
- stastistics → statistics (ngram-map.h)
- layed → laid (llama-k... | [
{
"path": "common/chat.cpp",
"patch": "@@ -221,7 +221,7 @@ using chat_template_caps = jinja::caps;\n struct common_chat_templates {\n bool add_bos;\n bool add_eos;\n- bool has_explicit_template; // Model had builtin template or template overridde was specified.\n+ bool has_explicit_template; ... | 2026-03-31T11:50:51 |
golang/go | f7475a0af3169d3d91f6071646defcf103393cc0 | 22b5c145fb85771cdc5d16cd6aa8294bcf010d46 | crypto/internal/fips140/bigmod: add Nat.InverseVarTime
Will be needed for RSA key generation.
We now require Modulus to be > 1 because we don't want to worry about 1
being out of range. There is no use for a Modulus of 1 anyway, and we
already return an error from NewModulus.
Ported from https://cs.opensource.google... | [
{
"path": "src/crypto/internal/fips140/bigmod/nat.go",
"patch": "@@ -473,15 +473,16 @@ func minusInverseModW(x uint) uint {\n \treturn -y\n }\n \n-// NewModulus creates a new Modulus from a slice of big-endian bytes.\n+// NewModulus creates a new Modulus from a slice of big-endian bytes. The\n+// modulus mu... | 2024-11-28T09:20:58 |
facebook/react | f533cee8cb4fb54c170230741eea7902cb41ee06 | 2c1117a8d008e34eb77eaaf7b8ef315a38644735 | Add useFormStatus to Flight fixture (#26773) | [
{
"path": "fixtures/flight/src/Button.js",
"patch": "@@ -1,29 +1,30 @@\n 'use client';\n \n import * as React from 'react';\n-import {flushSync} from 'react-dom';\n+import {experimental_useFormStatus as useFormStatus} from 'react-dom';\n import ErrorBoundary from './ErrorBoundary.js';\n \n-export default fu... | 2023-05-03T19:29:32 |
electron/electron | 27ddf19f3ce34f0153d29e23f68b6c38b206f296 | 4633376b28293ed74d88cf292c2539824c3bd795 | chore: use pylint-2.7 (#33232)
* chore: use pylint-2.7
* chore: fix pylint errors | [
{
"path": "script/lint.js",
"patch": "@@ -103,7 +103,7 @@ const LINTERS = [{\n const rcfile = path.join(DEPOT_TOOLS, 'pylintrc');\n const args = ['--rcfile=' + rcfile, ...filenames];\n const env = Object.assign({ PYTHONPATH: path.join(ELECTRON_ROOT, 'script') }, process.env);\n- spawnAndCheck... | 2022-03-23T00:17:35 |
huggingface/transformers | 2caa05deb31d7a8e641bbf6b64571fa4fc9c593e | a4fdaa5f72bdbdd1285baee05cf4c75820917fd2 | Fix weight decay exclusions in `run_*_no‑trainer.py` examples (#42769)
* fix(run_*_no_trainer.py): re-using `trainer.py` way to handle decay parameters
* added back useful comment
* Apply repo consistency fixes
---------
Co-authored-by: github-actions[bot] <github-actions[bot]@users.noreply.github.com> | [
{
"path": "examples/pytorch/language-modeling/run_clm_no_trainer.py",
"patch": "@@ -52,6 +52,7 @@\n from accelerate.utils import set_seed\n from datasets import load_dataset\n from huggingface_hub import HfApi\n+from torch import nn\n from torch.utils.data import DataLoader\n from tqdm.auto import tqdm\n \n... | 2026-02-12T14:24:54 |
ollama/ollama | a6ef73f4f26a22cc605516113625a404bd064250 | c2f5d6662ba696b94455eaaa298a797d56fdca5c | ggml: Fix race that resulted in "context canceled" when loading
Successfully completing processing with an errgroup cancels the
associated context. However, we also have a goroutine that is checking
for cancelation of the context. As a result, there is a race where
the goroutine can pick up the cancelation and report ... | [
{
"path": "ml/backend/ggml/ggml.go",
"patch": "@@ -341,6 +341,11 @@ func New(ctx context.Context, r *os.File, params ml.BackendParams) (ml.Backend,\n \n \t\t\tvar s uint64\n \t\t\tfor s < t.Size() {\n+\t\t\t\t// Stop if either the parent context has been canceled or if any of the other tensors returned an e... | 2025-05-02T00:06:53 |
ggml-org/llama.cpp | 41361c8599d04b5792edbcda22b168cc58212b17 | 62278cedde81e0ed79d0f647999eef02daebbae5 | common : move up common_init() and fix Windows UTF-8 logs (#21176)
The build info is now only for debug, so we avoid the duplicate
with `--version`.
The UTF-8 setup at the beginning is needed to avoid logging
garbage on Windows.
Signed-off-by: Adrien Gallouët <angt@huggingface.co> | [
{
"path": "common/common.cpp",
"patch": "@@ -359,6 +359,11 @@ bool parse_cpu_mask(const std::string & mask, bool (&boolmask)[GGML_MAX_N_THREAD\n }\n \n void common_init() {\n+#if defined(_WIN32)\n+ SetConsoleOutputCP(CP_UTF8);\n+ SetConsoleCP(CP_UTF8);\n+#endif\n+\n llama_log_set(common_log_defaul... | 2026-03-31T10:53:41 |
golang/go | 797141e94c4b6905dce90238cbc6b8748dfe1026 | b7e450bf27f28f60e574ac4ee4db165f771669a6 | doc/next: document buildtag changes
Fixes #64127
Change-Id: I1562953caa3b1b2bc5dd3b7692671e0f3d5d2b9b
Reviewed-on: https://go-review.googlesource.com/c/go/+/632355
Commit-Queue: Tim King <taking@google.com>
Reviewed-by: Alan Donovan <adonovan@google.com>
LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-account... | [
{
"path": "doc/next/3-tools.md",
"patch": "@@ -49,6 +49,13 @@ with no other arguments. Such calls are nearly always a mistake\n as the value of `s` may contain the `%` symbol; use `fmt.Print` instead.\n See [#60529](/issue/60529).\n \n+<!-- go.dev/issue/64127 -->\n+The existing `buildtag` analyzer now repor... | 2024-11-27T21:57:06 |
facebook/react | 407e7b0c620d1bb20ce52ccaa8e8ae555ab3edc4 | 7e990419c1314252ba78d2b0fa14c8dddaab72d4 | [snap runner] debug mode | [
{
"path": "compiler/forget/packages/snap/src/compiler-worker.ts",
"patch": "@@ -28,9 +28,11 @@ export type TestResult = {\n \n export async function compile(\n compilerPath: string,\n+ loggerPath: string,\n fixturesDir: string,\n fixture: string,\n- compilerVersion: number\n+ compilerVersion: numbe... | 2023-05-03T18:50:27 |
electron/electron | 4633376b28293ed74d88cf292c2539824c3bd795 | 8ad1470d08435de405b6738ef546d5ca95559fd0 | test: fix crash on image.crop (#33148)
* test: fix crash on image.crop
* Trigger CI | [
{
"path": "spec-main/screen-helpers.ts",
"patch": "@@ -41,7 +41,8 @@ const formatHexByte = (val: number): string => {\n * Get the hex color at the given pixel coordinate in an image.\n */\n export const getPixelColor = (image: Electron.NativeImage, point: Electron.Point): string => {\n- const pixel = ima... | 2022-03-23T00:14:49 |
huggingface/transformers | f013b342c50e81dc138fdb21d58325c1c51d31b8 | 32def650040d219feb54e2aff6e1d8a760f32e12 | Add explicit utf-8 encoding to CircleCI scripts for Windows compatibility (#43925)
Fix: Add explicit utf-8 encoding to CircleCI scripts for Windows compatibility | [
{
"path": ".circleci/create_circleci_config.py",
"patch": "@@ -121,7 +121,7 @@ def __post_init__(self):\n test_file = os.path.join(\"test_preparation\" , f\"{self.job_name}_test_list.txt\")\n print(\"Looking for \", test_file)\n if os.path.exists(test_file):\n- ... | 2026-02-12T13:59:01 |
ollama/ollama | c2f5d6662ba696b94455eaaa298a797d56fdca5c | 57fb759f3cb0716eeed5b59b047a7e141d1659d2 | ollamarunner: Re-enable worst case graph preallocation.
Worst case graph preallocation was disabled by a27462b
"ollamarunner: Temporarily disable worst case graph preallocation"
since it caused crashes with large batches when not using the GPU.
This backports upstream llama.cpp commit f057808
"ggml: Don't assert fail... | [
{
"path": "llama/patches/0018-ggml-Don-t-assert-fail-when-tensor-data-changes-1322.patch",
"patch": "@@ -0,0 +1,38 @@\n+From 0000000000000000000000000000000000000000 Mon Sep 17 00:00:00 2001\n+From: Jesse Gross <jesse@kernel.org>\n+Date: Thu, 1 May 2025 13:46:10 -0700\n+Subject: [PATCH] ggml: Don't assert f... | 2025-05-02T18:24:19 |
ggml-org/llama.cpp | 90aa83c6bdaa6ea82e1af5a02f77ff80088653d0 | fcc2d598c8da431d260da560f8aeeeb181702063 | common: add bounds check in common_init_result::sampler to prevent segfault on failed model load (#21082)
* common: add bounds check in common_init_result::sampler to prevent segfault on failed model load
* Revert a308e584cae3fa8cee1d739a858a2d780f1de009
* Add regression test
* Remove regression test for init-fail ... | [
{
"path": "common/common.cpp",
"patch": "@@ -1243,6 +1243,9 @@ llama_context * common_init_result::context() {\n }\n \n common_sampler * common_init_result::sampler(llama_seq_id seq_id) {\n+ if (seq_id < 0 || seq_id >= (int) pimpl->samplers.size()) {\n+ return nullptr;\n+ }\n return pimpl->... | 2026-03-31T10:04:42 |
golang/go | b7e450bf27f28f60e574ac4ee4db165f771669a6 | 2a93bd0d79484281b9706e2d66a0b21b42da66de | doc/next: document copylock changes
Fixes #66387
Change-Id: Ida9381d1ea83bcceaba460014fac3d0c13ccdbff
Reviewed-on: https://go-review.googlesource.com/c/go/+/632315
LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com>
Commit-Queue: Tim King <taking@google.com>
Reviewed-by: Alan Don... | [
{
"path": "doc/next/3-tools.md",
"patch": "@@ -49,6 +49,15 @@ with no other arguments. Such calls are nearly always a mistake\n as the value of `s` may contain the `%` symbol; use `fmt.Print` instead.\n See [#60529](/issue/60529).\n \n+<!-- go.dev/issue/66387 -->\n+The existing `copylock` analyzer now repor... | 2024-11-27T21:13:07 |
facebook/react | 7e990419c1314252ba78d2b0fa14c8dddaab72d4 | 253b05f28d02c2403b3f8210ee2b20182a054253 | [snap tester] Handle unexpected errors by failing fixture | [
{
"path": "compiler/forget/packages/snap/src/compiler-worker.ts",
"patch": "@@ -23,6 +23,7 @@ export type TestResult = {\n outputPath: string;\n actual: string | null; // null == input did not exist\n expected: string | null; // null == output did not exist\n+ unexpectedError: string | null;\n };\n \... | 2023-05-03T18:50:25 |
huggingface/transformers | 32def650040d219feb54e2aff6e1d8a760f32e12 | 85147681c76d5a9c2b6979305c076cbb635619b8 | Fix flaky test for multimodal LLMs (#43944) | [
{
"path": "tests/generation/test_utils.py",
"patch": "@@ -1343,7 +1343,10 @@ def test_generate_continue_from_past_key_values(self):\n # if there are multimodal data which don't belong anywhere inside `text_tokens`\n keys_to_pop = []\n for key in inputs:\n- ... | 2026-02-12T13:30:16 |
ggml-org/llama.cpp | fcc2d598c8da431d260da560f8aeeeb181702063 | 4453e77561145a350a37141659654d25da113681 | fix: include API key in CORS proxy requests for MCP connections (#21193)
* fix: include API key in CORS proxy requests for MCP connections
When llama-server is started with --api-key-file and --webui-mcp-proxy,
the /cors-proxy endpoint requires authentication. The WebUI was not
including the Authorization header in p... | [
{
"path": "tools/server/webui/src/lib/services/mcp.service.ts",
"patch": "@@ -42,6 +42,7 @@ import type {\n import {\n \tbuildProxiedUrl,\n \tbuildProxiedHeaders,\n+\tgetAuthHeaders,\n \tthrowIfAborted,\n \tisAbortError,\n \tcreateBase64DataUrl\n@@ -124,7 +125,14 @@ export class MCPService {\n \t\tconst req... | 2026-03-31T08:52:34 |
electron/electron | 81318f0acc59f6acbc74f1baa9cbe1e4411f53f8 | 956406a1934e9f71935103a67f13cbd7b571304d | fix: disable SIGUSR1 when --inspect is disabled (#33188) | [
{
"path": "patches/node/.patches",
"patch": "@@ -33,3 +33,4 @@ darwin_translate_eprototype_to_econnreset_3413.patch\n darwin_bump_minimum_supported_version_to_10_15_3406.patch\n fix_failing_node_js_test_on_outdated.patch\n be_compatible_with_cppgc.patch\n+feat_add_knostartdebugsignalhandler_to_environment_t... | 2022-03-22T07:51:04 |
ollama/ollama | 074bac844714b3a011d1cf6ebc40c169b10d1aef | 8e8f2c6d67ff3ee758102f197bb1b347ed1e97bd | kvcache: Log batch size if we can't find a slot
In some cases, we can't find a cache slot when using sliding window
attention. It would be helpful in this (and other cases) to know what
the batch size is.
Bug #10127 | [
{
"path": "kvcache/causal.go",
"patch": "@@ -239,7 +239,7 @@ func (c *Causal) findStartLoc() (int, error) {\n \t\t}\n \t}\n \n-\treturn 0, fmt.Errorf(\"%w (length: %v)\", ErrKvCacheFull, len(c.cells))\n+\treturn 0, fmt.Errorf(\"%w (cache: %v batch: %v)\", ErrKvCacheFull, len(c.cells), c.curBatchSize)\n }\n ... | 2025-05-01T20:45:32 |
golang/go | bcb934ad11060b4ed45663cf6e25bd7b7e92c1bb | 91d7ab2cefcc653f8b438fbfaa48d504dbfa4f00 | go/types, types2: fix printing of error message with variadic calls
Distinguish between variadic signatures and argument lists to
(possibly variadic) functions and place `...` before or after
the last type in the list of types.
Fixes a panic.
Fixes #70526.
Change-Id: I77aba8f50984a21ebcdb62582030f2d0fe0eb097
Review... | [
{
"path": "src/cmd/compile/internal/types2/assignments.go",
"patch": "@@ -295,7 +295,11 @@ func varTypes(list []*Var) (res []Type) {\n // ti's are user-friendly string representations for the given types.\n // If variadic is set and the last type is a slice, its string is of\n // the form \"...E\" where E i... | 2024-11-27T19:36:53 |
facebook/react | 8a25302c668d6f9a24f6680fb4947e9b388bb7d9 | 2c2476834a7c739ca239750b73f74aa1df144a93 | fix[dynamic-scripts-injection]: unregister content scripts before registration (#26765)
## Summary
Fixes #26756.
DevTools is failing to inject `__REACT_DEVTOOLS_GLOBAL_HOOK__` hook in
incognito mode. This is not happening straight-forward, but if extension
is toggled on and off, the next time I try to open it I ... | [
{
"path": "packages/react-devtools-extensions/src/background.js",
"patch": "@@ -6,38 +6,47 @@ import {IS_FIREFOX, EXTENSION_CONTAINED_VERSIONS} from './utils';\n \n const ports = {};\n \n-if (!IS_FIREFOX) {\n- // equivalent logic for Firefox is in prepareInjection.js\n- // Manifest V3 method of injecting ... | 2023-05-03T16:27:39 |
huggingface/transformers | 85147681c76d5a9c2b6979305c076cbb635619b8 | 0afacc2a451d0e5270faab31179e4982bba2954d | Fix docker files (#43946)
fix
Co-authored-by: ydshieh <ydshieh@users.noreply.github.com> | [
{
"path": "docker/transformers-all-latest-gpu/Dockerfile",
"patch": "@@ -80,7 +80,7 @@ RUN python3 -m pip install --no-cache-dir git+https://github.com/huggingface/pef\n # For bettertransformer\n RUN python3 -m pip install --no-cache-dir git+https://github.com/huggingface/optimum@main#egg=optimum\n # For ke... | 2026-02-12T13:08:16 |
ollama/ollama | 8e8f2c6d67ff3ee758102f197bb1b347ed1e97bd | 938e8447e8b8e107047b5d30515c2e589d185d6d | ollamarunner: Fix memory leak when processing images
The context (and therefore associated input tensors) was not being
properly closed when images were being processed. We were trying to
close them but in reality we were closing over an empty list, preventing
anything from actually being freed.
Fixes #10434 | [
{
"path": "runner/ollamarunner/runner.go",
"patch": "@@ -34,14 +34,10 @@ import (\n \t_ \"github.com/ollama/ollama/model/models\"\n )\n \n-type contextList struct {\n-\tlist []ml.Context\n-}\n-\n type Sequence struct {\n \t// ctxs are used for allocating tensors that last the lifetime of the sequence, such ... | 2025-05-01T18:34:02 |
electron/electron | 956406a1934e9f71935103a67f13cbd7b571304d | 0af2b8de73ab33f2ae8ecc285e2e9a247e09aaa7 | fix: use stricter options in SecStaticCodeCheckValidity (#33368)
* fix: use stricter options in SecStaticCodeCheckValidity
* Update patches/squirrel.mac/fix_use_kseccschecknestedcode_kseccsstrictvalidate_in_the_sec.patch
Co-authored-by: John Kleinschmidt <jkleinsc@electronjs.org>
Co-authored-by: John Kleinsch... | [
{
"path": "patches/squirrel.mac/.patches",
"patch": "@@ -1,2 +1,3 @@\n build_add_gn_config.patch\n fix_ensure_that_self_is_retained_until_the_racsignal_is_complete.patch\n+fix_use_kseccschecknestedcode_kseccsstrictvalidate_in_the_sec.patch",
"additions": 1,
"deletions": 0,
"language": "Unknown"
... | 2022-03-22T07:19:46 |
ggml-org/llama.cpp | 4453e77561145a350a37141659654d25da113681 | 26dac845cc433e35f50374c198c937a0c92b09d3 | server/webui: cleanup dual representation approach, simplify to openai-compat (#21090)
* server/webui: cleanup dual representation approach, simplify to openai-compat
* feat: Fix regression for Agentic Loop UI
* chore: update webui build output
* refactor: Post-review code improvements
* chore: update webui build ... | [
{
"path": "tools/server/webui/src/lib/components/app/chat/ChatMessages/ChatMessage.svelte",
"patch": "@@ -4,7 +4,7 @@\n \timport { getChatActionsContext, setMessageEditContext } from '$lib/contexts';\n \timport { chatStore, pendingEditMessageId } from '$lib/stores/chat.svelte';\n \timport { conversationsSto... | 2026-03-31T08:42:06 |
golang/go | 91d7ab2cefcc653f8b438fbfaa48d504dbfa4f00 | 4f78aa9e8bc909395bb891b12586ea0a7c9dfff1 | cmd/internal/obj: handle static assembly symbols correctly in FIPS check
Static symbols don't have the package prefix, so we need to identify
them specially.
Change-Id: Iaa0456de802478f6a257164e9703f18f8dc7eb50
Reviewed-on: https://go-review.googlesource.com/c/go/+/631975
Reviewed-by: Cherry Mui <cherryyz@google.com>... | [
{
"path": "src/cmd/internal/obj/fips140.go",
"patch": "@@ -221,47 +221,55 @@ func (s *LSym) setFIPSType(ctxt *Link) {\n \t\treturn\n \t}\n \n-\t// Name must begin with crypto/internal/fips140, then dot or slash.\n-\t// The quick check for 'c' before the string compare is probably overkill,\n-\t// but this f... | 2024-11-26T16:40:28 |
huggingface/transformers | 0afacc2a451d0e5270faab31179e4982bba2954d | d5131eb25ab0720bdef8f97dfc2213b503a277a6 | Fix bark test (#43942)
* fix bark
* fix | [
{
"path": "tests/models/bark/test_modeling_bark.py",
"patch": "@@ -634,16 +634,30 @@ def test_save_load_strict(self):\n model2, info = model_class.from_pretrained(tmpdirname, output_loading_info=True)\n self.assertEqual(info[\"missing_keys\"], set())\n \n- @unittest.skip(\n- ... | 2026-02-12T11:29:38 |
facebook/react | 9a12e8ba58a14288359036b130c1e86ae579da84 | 8292c65d8456fa75ab425c2e2754417780581cea | Support OptionalCallExpression as LHS of LogicalExpression
A common idiom is to map over some possibly-missing list of items from a data
payload and fall back to an empty array:
```javascript
const renderedItems = data?.items?.map(renderItem) ?? [];
```
The way we were lowering OptionalCallExpression meant t... | [
{
"path": "compiler/forget/src/HIR/BuildHIR.ts",
"patch": "@@ -1093,34 +1093,72 @@ function lowerExpression(\n const loc = expr.node.loc ?? GeneratedSource;\n const place = buildTemporaryPlace(builder, loc);\n const continuationBlock = builder.reserve(builder.currentBlockKind());\n+ c... | 2023-05-02T22:00:11 |
ggml-org/llama.cpp | 08f21453aec846867b39878500d725a05bd32683 | 84ae8434d0d00b52a8bab7f584b2963e129ccbfc | opencl: add q4_K gemm and gemv kernels for Adreno (#20919)
* opencl: add q4_K gemm and gemv kernels for Adreno
* opencl: fix whitespace
* opencl: add workarounds for compiler bugs on older devices
* opencl: handle fp16 denorm on X Elite
* opencl: fix kernel build error
* opencl: fix whitespace
* opencl: make q4_... | [
{
"path": "ggml/src/ggml-opencl/CMakeLists.txt",
"patch": "@@ -114,6 +114,8 @@ set(GGML_OPENCL_KERNELS\n gemv_noshuffle_q4_1_f32\n gemm_noshuffle_q4_1_f32\n gemv_noshuffle_general_q8_0_f32\n+ gemv_noshuffle_q4_k_f32\n+ gemm_noshuffle_q4_k_f32\n gemv_noshuffle_q6_k_f32\n gemm_noshuf... | 2026-03-30T19:19:16 |
ollama/ollama | a7835c671615d71280ca7dba7264bd05a4f90915 | ad3c7c9bda3b2db9a6887f65e3134c093333d3d5 | fix: write gguf padding (#10510)
* add gguf_test
* fix padding
padding was being added to offset but not to the running count | [
{
"path": "fs/ggml/gguf.go",
"patch": "@@ -531,11 +531,12 @@ func WriteGGUF(ws io.WriteSeeker, kv KV, ts []Tensor) error {\n \n \tvar s uint64\n \tfor _, t := range ts {\n-\t\tt.Offset = s + uint64(ggufPadding(int64(s), int64(alignment)))\n+\t\tt.Offset = s\n \t\tif err := ggufWriteTensorInfo(ws, t); err !=... | 2025-05-01T00:59:31 |
electron/electron | 0af2b8de73ab33f2ae8ecc285e2e9a247e09aaa7 | f5112632a395378a1e21757ebaa7ff4a1a13343a | docs: mark skipTaskbar as unsupported on Linux (#33226)
Fixes #33124. | [
{
"path": "docs/api/browser-window.md",
"patch": "@@ -186,8 +186,8 @@ It creates a new `BrowserWindow` with native properties as set by the `options`.\n mode. On macOS, also whether the maximize/zoom button should toggle full\n screen mode or maximize window. Default is `true`.\n * `simpleFullscre... | 2022-03-22T06:12:20 |
golang/go | 4f78aa9e8bc909395bb891b12586ea0a7c9dfff1 | 9dcf41908f9e315368fd043ccd9d67f2774b31e9 | debug/elf: check for multiplication overflow for shnum * shentsize
No test case because the problem can only happen for invalid data.
Let the fuzzer find cases like this.
For #47653
Fixes #70584
Change-Id: I8a69a27dcb5b258b88f8e01ebaf0ec20cfcd489b
Reviewed-on: https://go-review.googlesource.com/c/go/+/632035
Reviewe... | [
{
"path": "src/debug/elf/file.go",
"patch": "@@ -497,6 +497,9 @@ func NewFile(r io.ReaderAt) (*File, error) {\n \tif c < 0 {\n \t\treturn nil, &FormatError{0, \"too many sections\", shnum}\n \t}\n+\tif shnum > 0 && ((1<<64)-1)/uint64(shnum) < uint64(shentsize) {\n+\t\treturn nil, &FormatError{0, \"section h... | 2024-11-26T23:26:25 |
facebook/react | dd6a9d6a03a04ed21319da90c3c0967b53d7f738 | bfb84eed3b4c863474e0b2fa1d5dde3c638ec470 | Dont memoize hook calls in logical expressions
Fix the previous bug — this was a simple oversight, where FlattenScopesWithHooks
overrode `visitValue()` but failed to call `traverseValue()`. This meant that
when we reached compound expressions such as LogicalExpressions that we didn't
traverse into their nested val... | [
{
"path": "compiler/forget/src/ReactiveScopes/FlattenScopesWithHooks.ts",
"patch": "@@ -56,6 +56,7 @@ class Transform extends ReactiveFunctionTransform<State> {\n value: ReactiveValue,\n state: State\n ): void {\n+ this.traverseValue(id, value, state);\n if (\n value.kind === \"CallEx... | 2023-05-02T18:01:37 |
huggingface/transformers | d5131eb25ab0720bdef8f97dfc2213b503a277a6 | 9d9b012dcfc6cb4316588313f35dd6caef1d6b4b | Fix lifted_tensor in Gemma3n export which dynamo can't reason about (#43801)
* Fix lifted_tensor in Gemma3n which dynamo can't reason about
When using the torch.export path with this model we hit an issue on correction_coefs being modified with unknown side-effects the dynamo can't catch. So it lifts this tensor unne... | [
{
"path": "src/transformers/models/gemma3n/modeling_gemma3n.py",
"patch": "@@ -1145,12 +1145,14 @@ def correct(self, predictions: torch.Tensor, activated: torch.Tensor) -> torch.T\n innovation = innovation.repeat(self.config.altup_num_inputs, 1, 1, 1) # Repeat on dim0 to match predictions\n \n ... | 2026-02-12T09:58:33 |
ollama/ollama | ad3c7c9bda3b2db9a6887f65e3134c093333d3d5 | 415c8fcc3deee73e8a11822a962a87c7cb58d938 | strip out thinking tags in message history for qwen3 & r1 (#10490)
* strip out thinking tags in message history for qwen3 & r1
This is in advance of "proper" support where we'll make reasoning
configurable and we'll parse out thinking/reasoning tags and provide
them to the caller. These models expect there to be no t... | [
{
"path": "server/routes.go",
"patch": "@@ -18,6 +18,7 @@ import (\n \t\"os\"\n \t\"os/signal\"\n \t\"path/filepath\"\n+\t\"regexp\"\n \t\"slices\"\n \t\"strings\"\n \t\"syscall\"\n@@ -1512,6 +1513,7 @@ func (s *Server) ChatHandler(c *gin.Context) {\n \tif req.Messages[0].Role != \"system\" && m.System != \... | 2025-04-30T20:57:45 |
ggml-org/llama.cpp | 84ae8434d0d00b52a8bab7f584b2963e129ccbfc | ead417f01ce9769249e26fd1aaf700de83003a5c | CI : Enable CUDA and Vulkan ARM64 runners and fix CI/CD (#21122)
* CI: Enable CUDA and Vulkan ARM64 runners and fix CI/CD
Co-authored-by: Ts-sound <44093942+Ts-sound@users.noreply.github.com>
* Obtain source tag name from git tag
Co-authored-by: Sigbjørn Skjæret <sigbjorn.skjaeret@scala.com>
---------
Co-authored... | [
{
"path": ".devops/cpu.Dockerfile",
"patch": "@@ -36,7 +36,7 @@ RUN mkdir -p /app/full \\\n FROM ubuntu:$UBUNTU_VERSION AS base\n \n RUN apt-get update \\\n- && apt-get install -y libgomp1 curl\\\n+ && apt-get install -y libgomp1 curl \\\n && apt autoremove -y \\\n && apt clean -y \\\n && ... | 2026-03-30T18:24:37 |
electron/electron | f5112632a395378a1e21757ebaa7ff4a1a13343a | c262eac441a8fb69ee22b1ecb22979b8ce3b7948 | fix: pend bounds change when moving BrowserWindows (#33288)
* fix: ensure bounds changes apply when moving windows
* chore: remove unused queue include | [
{
"path": "shell/browser/native_window_views.cc",
"patch": "@@ -699,6 +699,13 @@ bool NativeWindowViews::IsFullscreen() const {\n }\n \n void NativeWindowViews::SetBounds(const gfx::Rect& bounds, bool animate) {\n+#if BUILDFLAG(IS_WIN)\n+ if (is_moving_ || is_resizing_) {\n+ pending_bounds_change_ = bou... | 2022-03-22T06:07:09 |
facebook/react | bfb84eed3b4c863474e0b2fa1d5dde3c638ec470 | c0b011935643645f29f1248aae7fc1238d636481 | Repro for memoized hook within logical expression
Repro of a bug in which we incorrect memoize hook calls that are inside logical
expressions (though the bug could occur for ternaries, optional calls, and
sequence expressions too). | [
{
"path": "compiler/forget/src/__tests__/fixtures/compiler/hook-inside-logical-expression.expect.md",
"patch": "@@ -0,0 +1,32 @@\n+\n+## Input\n+\n+```javascript\n+function Component(props) {\n+ const user = useFragment(graphql`...`, props.user) ?? {};\n+ return user.name;\n+}\n+\n+```\n+\n+## Code\n+\n+`... | 2023-05-02T17:47:48 |
ggml-org/llama.cpp | ead417f01ce9769249e26fd1aaf700de83003a5c | 64ac9ab66afa57f7012c83841022827dafb4aebe | jinja : handle empty expressions correctly (#20913)
* Reject empty computed member expressions before returning slices[0] from parse_member_expression_arguments().
* Treat empty computed member expressions with Jinja2 undefined semantics
Treat empty computed member expressions like `a[]` as undefined instead of
rais... | [
{
"path": "common/jinja/parser.cpp",
"patch": "@@ -539,6 +539,9 @@ class parser {\n statement_ptr step = slices.size() > 2 ? std::move(slices[2]) : nullptr;\n return mk_stmt<slice_expression>(start_pos, std::move(start), std::move(stop), std::move(step));\n }\n+ if (sl... | 2026-03-30T18:08:46 |
golang/go | 7d3d0334f9f58db5a0819da0963abb9ca0cba695 | 6405e60ca6be798c1f8c1d0365fd63b89b524df5 | crypto/tls: fix a broken link
Change-Id: I5d4baa454487a810f138334b613b412a5273311e
Reviewed-on: https://go-review.googlesource.com/c/go/+/631875
Reviewed-by: Filippo Valsorda <filippo@golang.org>
LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com>
Reviewed-by: Roland Shoemaker <ro... | [
{
"path": "src/crypto/tls/cipher_suites.go",
"patch": "@@ -235,7 +235,7 @@ var cipherSuitesTLS13 = []*cipherSuiteTLS13{ // TODO: replace with a map.\n // - Anything else comes before CBC_SHA256\n //\n // SHA-256 variants of the CBC ciphersuites don't implement any Lucky13\n-// countermeasures. See... | 2024-11-26T07:43:04 |
ollama/ollama | 415c8fcc3deee73e8a11822a962a87c7cb58d938 | 718eda1b3ec79b9b4a5f87ac8350d6ed7f63598b | Fix "Stopping..." scheduler hang (#10487)
* Adjust initial scheduler refCount
Ensure we only set the refCount on success
* sched: fix lock order inversion deadlock
Under certain race conditions, there was a scenario where the scheduler would
get into a deadlock while trying to update free space information while a ... | [
{
"path": "server/sched.go",
"patch": "@@ -441,10 +441,9 @@ func (s *Scheduler) load(req *LlmRequest, f *ggml.GGML, gpus discover.GpuInfoLis\n \t\testimatedVRAM: llama.EstimatedVRAM(),\n \t\testimatedTotal: llama.EstimatedTotal(),\n \t\tloading: true,\n-\t\trefCount: 1,\n \t}\n \trunner.nu... | 2025-04-30T18:26:52 |
huggingface/transformers | 9d9b012dcfc6cb4316588313f35dd6caef1d6b4b | 3a87a7a5eafc83d2b83a92336586cfacab17cacf | Prepare and keep track of position ids in `generate` (#43734)
* draft smth for now
* qwens
* fix assisted decoding, kinda. Get back later
* fix assisted decoding same model
* pad tokens should have a position ids of `0`, not `1`
* qwens fix generate
* other 3d rope models
* glm image
* colqwen
* fix repo mess... | [
{
"path": "src/transformers/generation/candidate_generator.py",
"patch": "@@ -303,6 +303,9 @@ def _update_past_and_masks(\n self.assistant_kwargs = _prepare_attention_mask(\n self.assistant_kwargs, input_ids.shape[-1], self.assistant_model.config.is_encoder_decoder\n ... | 2026-02-12T09:57:19 |
electron/electron | d79d3fc7d735b8b67a3121800d9c158d6e777af7 | 108ee7037f09fd623f473af5b3ecd943b5f6014a | test: fix and re-enable Network.getResponseBody test (#33227) | [
{
"path": "spec-main/api-debugger-spec.ts",
"patch": "@@ -133,39 +133,26 @@ describe('debugger module', () => {\n w.webContents.debugger.detach();\n });\n \n- // TODO(deepak1556): Fix and enable with upgrade\n- it.skip('handles valid unicode characters in message', (done) => {\n- try {\... | 2022-03-21T23:38:46 |
facebook/react | 67f4fb02130b1fe1856289e3b66bb0b8cca57ff7 | 8ea96ef84d8f08ed1846dec9e8ed20d2225db0d3 | Allow forms to skip hydration of hidden inputs (#26735)
This allows us to emit extra ephemeral data that will only be used on
server rendered forms.
First I refactored the shouldSkip functions to now just do that work
inside the canHydrate methods. This makes the Config bindings a little
less surface area but it... | [
{
"path": "packages/react-dom-bindings/src/client/ReactFiberConfigDOM.js",
"patch": "@@ -89,6 +89,7 @@ import {\n enableHostSingletons,\n enableTrustedTypesIntegration,\n diffInCommitPhase,\n+ enableFormActions,\n } from 'shared/ReactFeatureFlags';\n import {\n HostComponent,\n@@ -1038,160 +1039,18... | 2023-05-01T19:35:57 |
golang/go | 6405e60ca6be798c1f8c1d0365fd63b89b524df5 | 1ffadf146665c52b1d583bb20dc21a1fa6c02ead | cmd/trace: also show end stack traces
Fix a regression that appeared in 1.23 when it comes to the stack traces
shown in the trace viewer. In 1.22 and earlier, the viewer was always
showing end stack traces. In 1.23 and later the viewer started to
exclusively show start stack traces.
Showing only the start stack trace... | [
{
"path": "src/cmd/trace/gstate.go",
"patch": "@@ -257,6 +257,10 @@ func (gs *gState[R]) stop(ts trace.Time, stack trace.Stack, ctx *traceContext) {\n \tif gs.lastStopStack != trace.NoStack {\n \t\tstk = ctx.Stack(viewerFrames(gs.lastStopStack))\n \t}\n+\tvar endStk int\n+\tif stack != trace.NoStack {\n+\t\... | 2024-11-26T08:10:22 |
huggingface/transformers | 3a87a7a5eafc83d2b83a92336586cfacab17cacf | 4d5d49c34474be7cc2b6abd3179e7b317a17d8b1 | add openAI style `image_url` content support in `apply_chat_template` (#43786)
* add openAI style `image_url` content support in `apply_chat_template`
Signed-off-by: Liu, Kaixuan <kaixuan.liu@intel.com>
* update
Signed-off-by: Liu, Kaixuan <kaixuan.liu@intel.com>
* add xpu output
Signed-off-by: Liu, Kaixuan <kaix... | [
{
"path": "src/transformers/processing_utils.py",
"patch": "@@ -1726,6 +1726,23 @@ def apply_chat_template(\n is_batched = False\n conversations = [conversation]\n \n+ # Normalize OpenAI-style \"image_url\" content blocks to HuggingFace-style \"image\" blocks\n+ # OpenA... | 2026-02-12T09:48:14 |
ollama/ollama | 7bec2724a56ad990d66b9ca05e2b47191955596c | a27462b7085c7ba794f3b8da1553f4f1caa08ed0 | integration: fix embedding tests error handling (#10478)
The cleanup routine from InitServerconnection should run in the defer of the test case to properly detect failures and report the server logs | [
{
"path": "integration/embed_test.go",
"patch": "@@ -34,13 +34,15 @@ func cosineSimilarity[V float32 | float64](v1, v2 []V) V {\n func TestAllMiniLMEmbeddings(t *testing.T) {\n \tctx, cancel := context.WithTimeout(context.Background(), 2*time.Minute)\n \tdefer cancel()\n+\tclient, _, cleanup := InitServerCo... | 2025-04-29T18:57:54 |
electron/electron | 108ee7037f09fd623f473af5b3ecd943b5f6014a | 59246a4c7c27253848fd6c56bc7c9a137b85f123 | fix: IncrementCapturerCount doesn't increase the capturer count (#32973) | [
{
"path": "shell/browser/api/electron_api_web_contents.cc",
"patch": "@@ -3127,8 +3127,9 @@ void WebContents::IncrementCapturerCount(gin::Arguments* args) {\n // get stayAwake arguments if they exist\n args->GetNext(&stay_awake);\n \n- std::ignore =\n- web_contents()->IncrementCapturerCount(size, ... | 2022-03-21T23:38:03 |
ggml-org/llama.cpp | 64ac9ab66afa57f7012c83841022827dafb4aebe | cad2d3884c75e3b2e4736654295d1f1a5c29aa48 | CUDA : Fix CUB's argsort when nrows % block_size == 0 CCCL < 3.1 (#21181)
* CUDA: Fix CUB's argsort when nrows % block_size == 0 CCCL < 3.1
We wrongly calculated offset_grid as `ceildiv(nrows, block_size)`,
while it must be `ceildiv(nrows + 1, block_size)`. As a consequence, we
had uninitialized values in `offset_ite... | [
{
"path": "ggml/src/ggml-cuda/argsort.cu",
"patch": "@@ -47,9 +47,11 @@ void argsort_f32_i32_cuda_cub(ggml_cuda_pool & pool,\n #ifdef STRIDED_ITERATOR_AVAILABLE\n auto offset_iterator = cuda::make_strided_iterator(cuda::make_counting_iterator(0), ncols);\n #else\n- ggml_cuda_pool_alloc<int> offsets_a... | 2026-03-30T14:20:00 |
facebook/react | 86b0e91998a04b22bb54a95d54f4a7632efa902f | b12bea62d9cfd9a925f28cb2c93daeda3865a64e | Gate DevTools test to fix CI (#26742)
This test started failing recently in older versions of React because
the Scheduler priority inside a microtask is Normal instead of
Immediate. This is expected because microtasks are not Scheduler tasks;
it's an implementation detail.
I gated the test to only run in v17 bec... | [
{
"path": "packages/react-devtools-shared/src/__tests__/profilingCache-test.js",
"patch": "@@ -938,8 +938,10 @@ describe('ProfilingCache', () => {\n }\n });\n \n- // @reactVersion >= 18.0\n+ // @reactVersion = 17.0\n it('should handle unexpectedly shallow suspense trees', () => {\n+ // This tes... | 2023-04-29T15:14:16 |
golang/go | eab49f6a597a8224929232d5ecaba0281ceaa948 | 7b296625e478658cfbd43fd09e30dde01992ba6f | doc: add note about crypto/x509 serial generation
Fixes #67675
Change-Id: I102c779c2a0ccaf6572be354fec3153a0a0a32eb
Reviewed-on: https://go-review.googlesource.com/c/go/+/631683
LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com>
Auto-Submit: Roland Shoemaker <roland@golang.org>
... | [
{
"path": "doc/next/6-stdlib/99-minor/crypto/x509/67675.md",
"patch": "@@ -0,0 +1,3 @@\n+[`CreateCertificate`] will now generate a serial number using a RFC 5280\n+compliant method when passed a template with a nil [`Certificate.SerialNumber`]\n+field, instead of failing.\n\\ No newline at end of file",
... | 2024-11-26T23:13:49 |
huggingface/transformers | 4d5d49c34474be7cc2b6abd3179e7b317a17d8b1 | ae05b2ae619aa28fdfdcb8244009d585b7e1fed7 | Fix AttributeError in OwlViT conversion script for Python 3.10+ (#43922)
Fix AttributeError: Use collections.abc.MutableMapping for Python 3.10+ compatibility | [
{
"path": "src/transformers/models/owlvit/convert_owlvit_original_flax_to_hf.py",
"patch": "@@ -15,7 +15,7 @@\n https://github.com/google-research/scenic/tree/main/scenic/projects/owl_vit\"\"\"\n \n import argparse\n-import collections\n+from collections.abc import MutableMapping\n \n import jax\n import ja... | 2026-02-12T08:33:01 |
ollama/ollama | a27462b7085c7ba794f3b8da1553f4f1caa08ed0 | 6bf0b8193acadc5d595f320796d9876302ae0620 | ollamarunner: Temporarily disable worst case graph preallocation
When we later have a large batch running purely on a CPU, this
results the error:
GGML_ASSERT(talloc->buffer_id >= 0)
Disabling this means that we will incrementally reallocate memory
as the graph grows.
Fixes #10410 | [
{
"path": "runner/ollamarunner/runner.go",
"patch": "@@ -723,7 +723,9 @@ func (m *multiLPath) String() string {\n \treturn strings.Join(*m, \", \")\n }\n \n-func (s *Server) reserveWorstCaseGraph() error {\n+// TODO(jessegross): This is causing tensor allocation failures with large batches when not offloade... | 2025-04-29T17:48:39 |
Subsets and Splits
Assembly Language GitHub Issues
Retrieves a sample of assembly-language related commits with their details, but doesn't provide meaningful analysis or patterns beyond basic filtering.
Swift Compiler Issues Analysis
Retrieves all training data for the Swift programming language repository, providing basic filtering but offering limited analytical insight beyond identifying relevant code examples.